# Discordub

The only package to manage your user!

# TODO: rename Discordbot to Discordub

## How to install:

To install this package, run ```pip install discordub```

## Tutorial

Some things that this package includes is the send message & embed message!

```
import discordub as dub

#coming soon
```

### For the full documentation, please visit https://qloha.github.io/dicordub
